<?php
/*
Plugin Name: Tag Cloud Page
Description: Displays all the tags used on the site in a single page with pagination, along with a control panel for managing settings.
Version: 1.1
Author: mbsmgroup
*/

// Create a new page to display the tags
function tcp_create_tag_cloud_page() {
    $page_title = 'All Tags'; // Page title
    $page_slug = 'all-tags';  // Page slug

    // Check if the page exists
    if ( !get_page_by_path($page_slug) ) {
        // Create the page
        $new_page = array(
            'post_title'   => $page_title,
            'post_content' => '[tag_cloud]', // Page content, showing the tags here
            'post_status'  => 'publish',
            'post_author'  => 1, // User ID (typically 1 for the admin)
            'post_type'    => 'page',
        );
        
        wp_insert_post($new_page); // Insert the new page
    }
}
add_action('init', 'tcp_create_tag_cloud_page');

// Add settings page to the WordPress admin panel
function tcp_add_admin_menu() {
    add_menu_page(
        'Tag Cloud Settings',       // Title in the menu
        'Tag Cloud',                // Title in the sidebar menu
        'manage_options',           // Capability required
        'tag-cloud-settings',       // Menu slug
        'tcp_settings_page',        // Function to display the settings page
        'dashicons-tag',            // Icon for the menu item
        90                          // Position in the menu
    );
    
    // Add submenu for installation instructions
    add_submenu_page(
        'tag-cloud-settings',        // Parent slug
        'Installation Instructions', // Page title
        'Installation',              // Menu title
        'manage_options',            // Capability
        'tcp-installation',          // Menu slug
        'tcp_installation_page'      // Function to display the page content
    );
}
add_action('admin_menu', 'tcp_add_admin_menu');

// Settings page content
function tcp_settings_page() {
    ?>
    <div class="wrap">
        <h1>Tag Cloud Display Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('tcp_settings_group');
            do_settings_sections('tcp_settings_group');
            ?>
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="tcp_tags_per_page">Number of Tags per Page</label></th>
                    <td><input type="number" name="tcp_tags_per_page" value="<?php echo esc_attr(get_option('tcp_tags_per_page', 10)); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="tcp_order_by">Order Tags By</label></th>
                    <td>
                        <select name="tcp_order_by">
                            <option value="count" <?php selected(get_option('tcp_order_by', 'count'), 'count'); ?>>Number of Posts</option>
                            <option value="name" <?php selected(get_option('tcp_order_by', 'name'), 'name'); ?>>Name</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="tcp_order">Tag Order</label></th>
                    <td>
                        <select name="tcp_order">
                            <option value="DESC" <?php selected(get_option('tcp_order', 'DESC'), 'DESC'); ?>>Descending</option>
                            <option value="ASC" <?php selected(get_option('tcp_order', 'ASC'), 'ASC'); ?>>Ascending</option>
                        </select>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Register plugin settings
function tcp_register_settings() {
    register_setting('tcp_settings_group', 'tcp_tags_per_page');
    register_setting('tcp_settings_group', 'tcp_order_by');
    register_setting('tcp_settings_group', 'tcp_order');
}
add_action('admin_init', 'tcp_register_settings');

// Add installation instructions page content
function tcp_installation_page() {
    ?>
    <div class="wrap">
        <h1>Installation Instructions</h1>
        <p>Follow these steps to install and use the Tag Cloud Page plugin:</p>
        <ol>
            <li>Activate the plugin from the WordPress plugins page.</li>
            <li>Once activated, the plugin will automatically create a new page titled "All Tags" where all tags will be displayed.</li>
            <li>You can adjust the number of tags displayed per page and the order of tags from the "Tag Cloud" settings menu.</li>
            <li>To customize further, navigate to the "Tag Cloud" menu in the WordPress admin panel and select "Settings".</li>
        </ol>
        <p>If you need any assistance, feel free to contact us.</p>
    </div>
    <?php
}

// Add shortcode to display the tags
function tcp_display_tags($atts) {
    // Retrieve settings from the admin panel
    $tags_per_page = get_option('tcp_tags_per_page', 10);
    $order_by = get_option('tcp_order_by', 'count'); // Order by number of posts
    $order = get_option('tcp_order', 'DESC');
    
    // Retrieve all tags without pagination
    $args = array(
        'orderby' => 'count', // Order tags by the number of posts
        'order'   => $order,  // Ascending or Descending order
        'number'  => $tags_per_page,
    );
    $tags = get_tags($args);

    if (empty($tags)) {
        return 'No tags currently available.';
    }

    // Build the HTML for displaying tags in a table with links
    $output = '<table class="tag-cloud-table" style="width: 100%; border-collapse: collapse; text-align: left;">';
    $output .= '<thead><tr><th>Tag</th></tr></thead>';
    $output .= '<tbody>';
    
    foreach ($tags as $tag) {
        // Link to the tag
        $tag_link = esc_url(get_tag_link($tag->term_id));

        // Link to search the site using the tag
        $search_link = esc_url(home_url('/?s=' . urlencode($tag->name)));

        // Link to Google search using the tag
        $google_search_link = esc_url('https://www.google.com/search?q=' . urlencode($tag->name));
		$google_search_link_1 = esc_url('https://www.google.com/search?q=site:https://www.mbsm.tn ' . urlencode($tag->name));

        // Add a row to the table
        $output .= '<tr>';
        
        // Display the tag with the link
        $output .= '<td>';
        $output .= '<strong>' . esc_html($tag->name) . '</strong> (' . $tag->count . ' Posts)<br>'; // Tag name and number of posts

        // Add the search links below the tag
        $output .= '<a href="' . $tag_link . '" target="_blank" title="View posts associated with this tag">View Posts</a><br>';
        $output .= '<a href="' . $search_link . '" target="_blank" title="Search the site using this tag">Search Site</a><br>';
        $output .= '<a href="' . $google_search_link_1 . '" target="_blank" title="Search Google using this tag">Search Google in www.mbsm.tn</a><br>';
        
        // Add a line "Search on the net" with the Google link
        $output .= '<a href="' . $google_search_link . '" target="_blank" title="Search Google using this tag">Search on the Net</a>';
        
        $output .= '</td>';
        $output .= '</tr>';
    }
    
    $output .= '</tbody></table>';

    return $output;
}
add_shortcode('tag_cloud', 'tcp_display_tags');

// Add CSS styles to format the table
function tcp_add_styles() {
    echo '
    <style>
    .tag-cloud-table {
        width: 100%;
        border-collapse: collapse;
        margin: 20px 0;
    }

    .tag-cloud-table th, .tag-cloud-table td {
        padding: 10px;
        border: 1px solid #ddd;
        text-align: left;
    }

    .tag-cloud-table th {
        background-color: #f4f4f4;
        color: #333;
    }

    .tag-cloud-table tr:nth-child(even) {
        background-color: #f9f9f9;
    }

    .tag-cloud-table tr:hover {
        background-color: #eaeaea;
    }

    .tag-cloud-table td {
        font-size: 16px;
    }

    .tag-cloud-table td a {
        color: #0073aa;
        text-decoration: none;
        display: block;
        margin: 5px 0;
    }

    .tag-cloud-table td a:hover {
        text-decoration: underline;
    }
    </style>';
}
add_action('wp_head', 'tcp_add_styles');
?>
